@@ -1,9 +1,9 @@
 package Log::ger::Plugin::MultilevelLog;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-11'; # DATE
+our $DATE = '2021-01-31'; # DATE
 our $DIST = 'Log-ger'; # DIST
-our $VERSION = '0.037'; # VERSION
+our $VERSION = '0.038'; # VERSION
 
 use strict;
 use warnings;
@@ -86,7 +86,7 @@ sub get_hooks {
 }
 
 1;
-# ABSTRACT: Create a log($LEVEL, ...) subroutine/method
+# ABSTRACT: (DEPRECATED) Old name for Log::ger::Format::MultilevelLog
 
 __END__
 
@@ -96,74 +96,24 @@ __END__
 
 =head1 NAME
 
-Log::ger::Plugin::MultilevelLog - Create a log($LEVEL, ...) subroutine/method
+Log::ger::Plugin::MultilevelLog - (DEPRECATED) Old name for Log::ger::Format::MultilevelLog
 
 =head1 VERSION
 
-version 0.037
-
-=head1 SYNOPSIS
-
- use Log::ger::Plugin MultilevelLog => (
-     # sub_name => 'log_it',    # optional, defaults to 'log'
-     # method_name => 'log_it', # optional, defaults to 'log'
-     # exclusive => 1,          # optional, defaults to 0
- );
- use Log::ger;
-
- log('warn', 'This is a warning');
- log('debug', 'This is a debug, data is %s', $data);
+version 0.038
 
 =head1 DESCRIPTION
 
-The Log::ger default is to create separate C<log_LEVEL> subroutine (or C<LEVEL>
-methods) for each level, e.g. C<log_trace> subroutine (or C<trace> method),
-C<log_warn> (or C<warn>), and so on. But sometimes you might want a log routine
-that takes $level as the first argument. That is, instead of:
-
- log_warn('blah ...');
-
-or:
-
- $log->debug('Blah: %s', $data);
-
-you prefer:
-
- log('warn', 'blah ...');
-
-or:
-
- $log->log('debug', 'Blah: %s', $data);
-
-This plugin can create such log routine for you.
-
-Note: the multilevel log is slightly slower because of the extra argument and
-additional string level -> numeric level conversion. See benchmarks in
-L<Bencher::Scenarios::LogGer>.
-
-Note: the individual separate C<log_LEVEL> subroutines (or C<LEVEL> methods) are
-still installed, unless you specify configuration L</exclusive> to true.
+This plugin has been renamed to L<Log::ger::Format::MultilevelLog> in 0.038. The
+old name is provided for backward compatibility for now, but is deprecated and
+will be removed in the future. Please switch to the new name and be aware that
+format plugins only affect the current package.
 
 =for Pod::Coverage ^(.+)$
 
-=head1 CONFIGURATION
-
-=head2 sub_name
-
-String. Defaults to C<log>.
-
-=head2 method_name
-
-String. Defaults to C<log>.
-
-=head2 exclusive
-
-Boolean. If set to true, will block the generation of the default C<log_LEVEL>
-subroutines or C<LEVEL> methods (e.g. C<log_warn>, C<trace>, ...).
-
 =head1 SEE ALSO
 
-L<Log::ger::Plugin::HashArgs>
+L<Log::ger::Format::MultilevelLog>
 
 =head1 AUTHOR
 
@@ -171,7 +121,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
